#define _XOPEN_SOURCE 500

#include <stdio.h>
#include <stdlib.h>
#include <stdint.h>
#include <string.h>
#include <assert.h>

#include <caml/bigarray.h>
#include <caml/memory.h>

#include <sys/types.h>
#include <unistd.h>

CAMLprim value output_mask_c (value fd, value w, value m)
{
  CAMLparam3 (m, w, fd);

  // System with w<5 (less than 2.5-bit constraints) are supported by
  // faking 2.5-bit constraints.

  int x = Int_val(m);
  int f = Int_val(fd);
  uint32_t mask;
  switch (Int_val(w)) {
  case 3:
    mask = 1ULL<<(28-4*x);
    mask *= 7;
    break;
  case 4:
    mask = 1ULL<<(30-2*x);
    mask *= 3;
    break;
  case 5:
    mask = 1ULL<<(31-x);
    break;
  default:
    fprintf (stderr, "Stderr: width %i not supported\n", Int_val(w));
    exit (-1);
  };

  write(f, &mask, 4);
  CAMLreturn (Val_unit);
}

CAMLprim value output_int_c (value fd, value m)
{
  CAMLparam2 (m, fd);

  uint32_t x = Int_val(m);
  int f = Int_val(fd);
  write(f, &x, sizeof(x));

  CAMLreturn (Val_unit);
}

/*
external determinize_c : 
  (int, Bigarray.int16_unsigned_elt, Bigarray.c_layout) Bigarray.Array2.t ->
    int -> (int, Bigarray.int16_unsigned_elt, Bigarray.c_layout) Bigarray.Array1.t
      = "determinize_c"
*/

uint16_t* determinize_c (uint16_t* base, int x, int y, uint16_t set);

CAMLprim value determinize_c_stub (value bigarray, value set)
{
  CAMLparam2 (bigarray, set);

  int dimx = Bigarray_val(bigarray)->dim[0];
  int dimy = Bigarray_val(bigarray)->dim[1];

  assert(Is_long(set));
  uint16_t* ret = determinize_c(Data_bigarray_val(bigarray),
                                dimx, dimy, Long_val(set));

  CAMLreturn (alloc_bigarray_dims(BIGARRAY_UINT16|BIGARRAY_C_LAYOUT,
                                  1, ret, dimy));
}

uint16_t* determinize_c (uint16_t* b, int x, int y, uint16_t set) {
  uint16_t (*base)[y] = (void*) b;

  static uint16_t *data = NULL;
  static size_t datasize = 0;

  if (y*sizeof(uint16_t) > datasize) {
    data = realloc(data, y*sizeof(uint16_t));
  }

  memset(data, 0, y*sizeof(uint16_t));

  for (int i=0; i<x; i++) {
    if (set & (1<<i)) {
      for (int j=0; j<y; j++) {
        data[j] |= base[i][j];
      }
    }
  }

  /* printf ("\n[%i,%i] %i ->", x, y, set); */
  /* for (int j=0; j<y; j++) */
  /*   printf (" %i", data[j]); */
  /* printf("\n"); */

  return data;
}
