
(* Primitive lexer *)

{
  open Parser
}

let letter = ['a'-'z' 'A'-'Z' '@']
let digit = ['0'-'9']
let number = digit +
let ident = letter *
let integer = ['0'-'9']+
let space = [' ' '\t' '\n' ]
let comment = '#' [ ^ '\n' ]* '\n'

rule token = parse
  | "V" (number as n)   { Tvar (int_of_string n) }
  | "P" (number as n)   { Tpar (int_of_string n) }
  | "X" (number as n)   { Tmpar (int_of_string n) }
  | "M" (number as n)   { Tmacro (int_of_string n) }
  | "T" (number as n)   { Ttmp (int_of_string n) }
  (* | "S"               { TsignS } *)
  (* | "T"               { TsignT } *)
  (* | "U"               { TsignU } *)
  | "Mux" (number as n) { Tmux (int_of_string n) }
  | "HW" (number as n)  { Thw (int_of_string n) }
  | "0"                 { Tcst (false) }
  | "1"                 { Tcst (true) }
  | "+"                 { Tplus }
  | "-"                 { Tminus }
  | "^"                 { Txor }
  | "|"                 { Tor }
  | "&"                 { Tand }
  | "^^"                { Txor2 }
  | "||"                { Tor2 }
  | "&&"                { Tand2 }
  | "="                 { Teq }
  | "=="                { Teq2 }
  | "~"                 { Tnot }
  | ":"                 { Tdef }
  | ":="                { Tdefvar }
  | "("                 { Topen }
  | ")"                 { Tclose }
  | ","                 { Tcomma }
  | ";"                 { Tsep }
  | comment             { token lexbuf }
  | space               { token lexbuf }
  | eof                 { EOF }
and ruleTail acc = parse
  | eof { acc }
  | _* as str { ruleTail (acc ^ str) lexbuf }
