type token =
  | Tvar of (int)
  | Tpar of (int)
  | Tmacro of (int)
  | Ttmp of (int)
  | Tmpar of (int)
  | Tmux of (int)
  | Thw of (int)
  | Tcst of (bool)
  | Tminus
  | Tplus
  | Txor
  | Tor
  | Tand
  | Txor2
  | Tor2
  | Tand2
  | Topen
  | Tclose
  | Tcomma
  | Tsep
  | Teq
  | Teq2
  | Tnot
  | Tdef
  | Tdefvar
  | EOF

open Parsing;;
let _ = parse_error;;
# 3 "parser.mly"
  open Exp

  let varstbl = Hashtbl.create 8

  let makevar name exp = 
    Hashtbl.add varstbl name exp 

  let callvar name =
    Hashtbl.find varstbl name

  let macrostbl = Hashtbl.create 8

  let makemacro name exp = 
    Hashtbl.add macrostbl name exp 

  let callmacro name l =
    let rec subst = function
      | Sum  (i, x, y)    -> Sum  (i, subst x, subst y)
      | Sum3 (i, x, y, z) -> Sum3 (i, subst x, subst y, subst z)
      | Mux (i, l)        -> Mux (i, List.map subst l)
      | HW  (i, w, x)     -> HW  (i, w, subst x)
      | Bool (b, x, y)        -> Bool (b, subst x, subst y)
      | Var i when i < 0  -> List.nth l (-1-i)
      | Var i             -> Var i
      | Param i           -> Param i
      | Const i           -> Const i
    in subst (Hashtbl.find macrostbl name)

  (* Note: during parsing, the sum number is actually the initial carry *)

  let makesyst e =
    let nbsum = ref 0 in
    let nbvar = ref 0 in
    let nbpar = ref 0 in
    let htbl = Hashtbl.create 8 in
    let htbl2 = Hashtbl.create 8 in
    let initcarry:int list ref = ref [] in
    let rec f = function
      | Sum  (c, x, y)    ->
          let i = try
            Hashtbl.find htbl (c,x,y,Const false)
          with Not_found ->
            let n = !nbsum in
            Hashtbl.add htbl (c,x,y,Const false) n;
            initcarry := c::!initcarry;
            incr nbsum;
            n;
          in Sum  (i, f x, f y);
      | Sum3 (c, x, y, z)    ->
          let i = try
            Hashtbl.find htbl (c,x,y,z)
          with Not_found ->
            let n = !nbsum in
            Hashtbl.add htbl (c,x,y,z) n;
            initcarry := c::!initcarry;
            incr nbsum;
            n;
          in Sum3  (i, f x, f y, f z);
      | HW  (_, w, x)     ->
        let i = try
            Hashtbl.find htbl2 x
          with Not_found ->
            let n = !nbsum in
            Hashtbl.add htbl2 x n;
            initcarry := 0::!initcarry;
            incr nbsum;
            n;
        in HW  (i, w, f x)
      | Mux (i, l)        -> Mux (i, List.map f l)
      | Bool (b, x, y)    -> Bool (b, f x, f y)
      | Var i             -> if i+1 > !nbvar then nbvar := i+1; Var i
      | Param i           -> if i+1 > !nbpar then nbpar := i+1; Param i
      | Const i           -> Const i
    in let ee = List.map f e in {
      exps      = ee;
      nbvar     = !nbvar;
      nbparam   = !nbpar;
      nbsum     = !nbsum;
      initcarry = Array.of_list (List.rev !initcarry);
    }
# 113 "parser.ml"
let yytransl_const = [|
  265 (* Tminus *);
  266 (* Tplus *);
  267 (* Txor *);
  268 (* Tor *);
  269 (* Tand *);
  270 (* Txor2 *);
  271 (* Tor2 *);
  272 (* Tand2 *);
  273 (* Topen *);
  274 (* Tclose *);
  275 (* Tcomma *);
  276 (* Tsep *);
  277 (* Teq *);
  278 (* Teq2 *);
  279 (* Tnot *);
  280 (* Tdef *);
  281 (* Tdefvar *);
    0 (* EOF *);
    0|]

let yytransl_block = [|
  257 (* Tvar *);
  258 (* Tpar *);
  259 (* Tmacro *);
  260 (* Ttmp *);
  261 (* Tmpar *);
  262 (* Tmux *);
  263 (* Thw *);
  264 (* Tcst *);
    0|]

let yylhs = "\255\255\
\001\000\002\000\002\000\002\000\003\000\003\000\003\000\003\000\
\004\000\004\000\004\000\004\000\004\000\004\000\004\000\004\000\
\004\000\004\000\004\000\004\000\004\000\004\000\004\000\004\000\
\004\000\004\000\004\000\006\000\006\000\005\000\000\000"

let yylen = "\002\000\
\001\000\001\000\002\000\003\000\001\000\001\000\004\000\003\000\
\001\000\001\000\001\000\001\000\002\000\001\000\003\000\003\000\
\003\000\003\000\003\000\003\000\003\000\003\000\003\000\003\000\
\003\000\004\000\004\000\001\000\003\000\003\000\002\000"

let yydefred = "\000\000\
\000\000\000\000\010\000\011\000\000\000\000\000\012\000\000\000\
\000\000\009\000\000\000\000\000\002\000\031\000\001\000\000\000\
\000\000\006\000\000\000\000\000\000\000\000\000\000\000\000\000\
\014\000\000\000\000\000\000\000\003\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\025\000\004\000\024\000\
\023\000\015\000\017\000\018\000\000\000\000\000\000\000\016\000\
\000\000\000\000\026\000\027\000\007\000\029\000"

let yydgoto = "\002\000\
\014\000\015\000\016\000\040\000\018\000\041\000"

let yysindex = "\011\000\
\001\000\000\000\000\000\000\000\249\254\250\254\000\000\001\255\
\004\255\000\000\003\255\003\255\000\000\000\000\000\000\003\000\
\099\255\000\000\003\255\003\255\003\255\003\255\003\255\005\255\
\000\000\057\255\099\255\001\000\000\000\003\255\003\255\003\255\
\003\255\003\255\003\255\003\255\003\255\003\255\003\255\071\255\
\006\255\099\255\099\255\015\255\085\255\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\019\255\019\255\019\255\000\000\
\019\255\003\255\000\000\000\000\000\000\000\000"

let yyrindex = "\000\000\
\000\000\000\000\000\000\000\000\000\000\016\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\013\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\002\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\017\255\
\000\000\014\000\015\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\025\000\034\000\043\000\000\000\
\052\000\000\000\000\000\000\000\000\000\000\000"

let yygindex = "\000\000\
\000\000\251\255\000\000\026\000\000\000\234\255"

let yytablesize = 330
let yytable = "\044\000\
\013\000\013\000\029\000\003\000\004\000\024\000\025\000\007\000\
\008\000\019\000\010\000\001\000\005\000\030\000\008\000\014\000\
\020\000\022\000\021\000\011\000\023\000\019\000\047\000\059\000\
\019\000\012\000\017\000\030\000\031\000\032\000\033\000\034\000\
\060\000\021\000\028\000\062\000\026\000\027\000\000\000\038\000\
\000\000\000\000\022\000\000\000\000\000\042\000\043\000\000\000\
\045\000\000\000\000\000\020\000\000\000\017\000\000\000\048\000\
\049\000\050\000\051\000\052\000\053\000\054\000\055\000\056\000\
\057\000\030\000\031\000\032\000\033\000\034\000\035\000\036\000\
\037\000\000\000\046\000\000\000\000\000\038\000\039\000\030\000\
\031\000\032\000\033\000\034\000\035\000\036\000\037\000\000\000\
\000\000\058\000\000\000\038\000\039\000\030\000\031\000\032\000\
\033\000\034\000\035\000\036\000\037\000\000\000\061\000\000\000\
\000\000\038\000\039\000\030\000\031\000\032\000\033\000\034\000\
\035\000\036\000\037\000\000\000\000\000\000\000\000\000\038\000\
\039\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\003\000\004\000\005\000\006\000\007\000\008\000\009\000\
\010\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\011\000\000\000\013\000\013\000\013\000\028\000\012\000\
\014\000\014\000\014\000\014\000\014\000\014\000\014\000\014\000\
\005\000\030\000\008\000\014\000\014\000\014\000\019\000\019\000\
\019\000\000\000\019\000\019\000\019\000\000\000\019\000\021\000\
\021\000\021\000\000\000\021\000\021\000\021\000\000\000\021\000\
\022\000\022\000\022\000\000\000\022\000\022\000\022\000\000\000\
\022\000\020\000\020\000\020\000\000\000\020\000\020\000\020\000\
\000\000\020\000"

let yycheck = "\022\000\
\000\000\000\000\000\000\001\001\002\001\003\001\004\001\005\001\
\006\001\017\001\008\001\001\000\000\000\000\000\000\000\000\000\
\024\001\017\001\025\001\017\001\017\001\017\001\028\000\018\001\
\000\000\023\001\001\000\009\001\010\001\011\001\012\001\013\001\
\018\001\000\000\018\001\058\000\011\000\012\000\255\255\021\001\
\255\255\255\255\000\000\255\255\255\255\020\000\021\000\255\255\
\023\000\255\255\255\255\000\000\255\255\028\000\255\255\030\000\
\031\000\032\000\033\000\034\000\035\000\036\000\037\000\038\000\
\039\000\009\001\010\001\011\001\012\001\013\001\014\001\015\001\
\016\001\255\255\018\001\255\255\255\255\021\001\022\001\009\001\
\010\001\011\001\012\001\013\001\014\001\015\001\016\001\255\255\
\255\255\019\001\255\255\021\001\022\001\009\001\010\001\011\001\
\012\001\013\001\014\001\015\001\016\001\255\255\018\001\255\255\
\255\255\021\001\022\001\009\001\010\001\011\001\012\001\013\001\
\014\001\015\001\016\001\255\255\255\255\255\255\255\255\021\001\
\022\001\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\001\001\002\001\003\001\004\001\005\001\006\001\007\001\
\008\001\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\017\001\255\255\018\001\019\001\020\001\020\001\023\001\
\009\001\010\001\011\001\012\001\013\001\014\001\015\001\016\001\
\020\001\020\001\020\001\020\001\021\001\022\001\014\001\015\001\
\016\001\255\255\018\001\019\001\020\001\255\255\022\001\014\001\
\015\001\016\001\255\255\018\001\019\001\020\001\255\255\022\001\
\014\001\015\001\016\001\255\255\018\001\019\001\020\001\255\255\
\022\001\014\001\015\001\016\001\255\255\018\001\019\001\020\001\
\255\255\022\001"

let yynames_const = "\
  Tminus\000\
  Tplus\000\
  Txor\000\
  Tor\000\
  Tand\000\
  Txor2\000\
  Tor2\000\
  Tand2\000\
  Topen\000\
  Tclose\000\
  Tcomma\000\
  Tsep\000\
  Teq\000\
  Teq2\000\
  Tnot\000\
  Tdef\000\
  Tdefvar\000\
  EOF\000\
  "

let yynames_block = "\
  Tvar\000\
  Tpar\000\
  Tmacro\000\
  Ttmp\000\
  Tmpar\000\
  Tmux\000\
  Thw\000\
  Tcst\000\
  "

let yyact = [|
  (fun _ -> failwith "parser")
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : Exp.exp list) in
    Obj.repr(
# 123 "parser.mly"
              ( makesyst _1 )
# 322 "parser.ml"
               : Exp.syst))
; (fun __caml_parser_env ->
    Obj.repr(
# 126 "parser.mly"
      ( [] )
# 328 "parser.ml"
               : Exp.exp list))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : Exp.exp) in
    Obj.repr(
# 127 "parser.mly"
               ( [_1] )
# 335 "parser.ml"
               : Exp.exp list))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : Exp.exp) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : Exp.exp list) in
    Obj.repr(
# 128 "parser.mly"
                            ( _1::_3 )
# 343 "parser.ml"
               : Exp.exp list))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'expression) in
    Obj.repr(
# 132 "parser.mly"
             ( _1 )
# 350 "parser.ml"
               : Exp.exp))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'macro) in
    Obj.repr(
# 133 "parser.mly"
        ( Const true )
# 357 "parser.ml"
               : Exp.exp))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 3 : int) in
    let _3 = (Parsing.peek_val __caml_parser_env 1 : 'expression) in
    Obj.repr(
# 134 "parser.mly"
                              ( HW(0,_1,_3) )
# 365 "parser.ml"
               : Exp.exp))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : int) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'expression) in
    Obj.repr(
# 135 "parser.mly"
                          ( makevar _1 _3; Const true )
# 373 "parser.ml"
               : Exp.exp))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : bool) in
    Obj.repr(
# 138 "parser.mly"
       ( Const _1 )
# 380 "parser.ml"
               : 'expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : int) in
    Obj.repr(
# 139 "parser.mly"
       ( Var _1 )
# 387 "parser.ml"
               : 'expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : int) in
    Obj.repr(
# 140 "parser.mly"
       ( Param _1 )
# 394 "parser.ml"
               : 'expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : int) in
    Obj.repr(
# 141 "parser.mly"
        ( Var (-1-_1) )
# 401 "parser.ml"
               : 'expression))
; (fun __caml_parser_env ->
    let _2 = (Parsing.peek_val __caml_parser_env 0 : 'expression) in
    Obj.repr(
# 142 "parser.mly"
                  ( Bool ((fun x y -> not x), _2, Const true) )
# 408 "parser.ml"
               : 'expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : int) in
    Obj.repr(
# 143 "parser.mly"
       ( callvar _1 )
# 415 "parser.ml"
               : 'expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'expression) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'expression) in
    Obj.repr(
# 144 "parser.mly"
                              ( Bool ((<>), _1, _3) )
# 423 "parser.ml"
               : 'expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'expression) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'expression) in
    Obj.repr(
# 145 "parser.mly"
                              ( Bool ((=) , _1, _3) )
# 431 "parser.ml"
               : 'expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'expression) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'expression) in
    Obj.repr(
# 146 "parser.mly"
                              ( Bool ((||), _1, _3) )
# 439 "parser.ml"
               : 'expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'expression) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'expression) in
    Obj.repr(
# 147 "parser.mly"
                              ( Bool ((&&), _1, _3) )
# 447 "parser.ml"
               : 'expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'expression) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'expression) in
    Obj.repr(
# 148 "parser.mly"
                              ( Bool ((<>), _1, _3) )
# 455 "parser.ml"
               : 'expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'expression) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'expression) in
    Obj.repr(
# 149 "parser.mly"
                              ( Bool ((=) , _1, _3) )
# 463 "parser.ml"
               : 'expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'expression) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'expression) in
    Obj.repr(
# 150 "parser.mly"
                              ( Bool ((||), _1, _3) )
# 471 "parser.ml"
               : 'expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'expression) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'expression) in
    Obj.repr(
# 151 "parser.mly"
                              ( Bool ((&&), _1, _3) )
# 479 "parser.ml"
               : 'expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'expression) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'expression) in
    Obj.repr(
# 152 "parser.mly"
                               (
  match _1 with
    | Sum(c,a,b) -> output_string stderr "Sum3!\n"; Sum3(c,a,b,_3)
    | _          -> Sum (0, _1, _3)
)
# 491 "parser.ml"
               : 'expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'expression) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'expression) in
    Obj.repr(
# 157 "parser.mly"
                               (
  match _1 with
    | Sum(c,a,b) -> output_string stderr "Sum3!\n"; Sum3(c+1,a,b,Bool((<>), _3, Const true))
    | _          -> Sum (1, _1, Bool((<>), _3, Const true))
)
# 503 "parser.ml"
               : 'expression))
; (fun __caml_parser_env ->
    let _2 = (Parsing.peek_val __caml_parser_env 1 : 'expression) in
    Obj.repr(
# 162 "parser.mly"
                          ( _2 )
# 510 "parser.ml"
               : 'expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 3 : int) in
    let _3 = (Parsing.peek_val __caml_parser_env 1 : 'expressions) in
    Obj.repr(
# 163 "parser.mly"
                                  ( callmacro _1 _3 )
# 518 "parser.ml"
               : 'expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 3 : int) in
    let _3 = (Parsing.peek_val __caml_parser_env 1 : 'expressions) in
    Obj.repr(
# 164 "parser.mly"
                                  (
    if (List.length _3) <> (_1 + (1 lsl _1)) then
      failwith "Bad number of arguments for Mux call";
    Mux (_1, _3) )
# 529 "parser.ml"
               : 'expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'expression) in
    Obj.repr(
# 170 "parser.mly"
             ( [_1] )
# 536 "parser.ml"
               : 'expressions))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'expression) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'expressions) in
    Obj.repr(
# 171 "parser.mly"
                                ( _1::_3 )
# 544 "parser.ml"
               : 'expressions))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : int) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'expression) in
    Obj.repr(
# 174 "parser.mly"
                           ( makemacro _1 _3 )
# 552 "parser.ml"
               : 'macro))
(* Entry system *)
; (fun __caml_parser_env -> raise (Parsing.YYexit (Parsing.peek_val __caml_parser_env 0)))
|]
let yytables =
  { Parsing.actions=yyact;
    Parsing.transl_const=yytransl_const;
    Parsing.transl_block=yytransl_block;
    Parsing.lhs=yylhs;
    Parsing.len=yylen;
    Parsing.defred=yydefred;
    Parsing.dgoto=yydgoto;
    Parsing.sindex=yysindex;
    Parsing.rindex=yyrindex;
    Parsing.gindex=yygindex;
    Parsing.tablesize=yytablesize;
    Parsing.table=yytable;
    Parsing.check=yycheck;
    Parsing.error_function=parse_error;
    Parsing.names_const=yynames_const;
    Parsing.names_block=yynames_block }
let system (lexfun : Lexing.lexbuf -> token) (lexbuf : Lexing.lexbuf) =
   (Parsing.yyparse yytables 1 lexfun lexbuf : Exp.syst)
